#!/bin/bash

set -e
export ENVIRONMENT=${ENVIRONMENT:-"development"}
echo "============Starting script for savings plan allocation in environment: $ENVIRONMENT=============="

#-------------------------------------Setup Script Directory------------------------------------------------------------

if [ -d "${PWD}/deploy" ]; then
  SCRIPT_DIR="${PWD}/deploy"
else
  SCRIPT_DIR="${PWD}"
fi
echo "SCRIPT_DIR: $SCRIPT_DIR"
#-------------------------------------Setup Environment-----------------------------------------------------------------

export AWS_REGION=${AWS_REGION:-"us-east-1"}
export KAFKA_HOST=${KAFKA_HOST:-localhost:9092}
export NG_RABBITMQ_HOST=${NG_RABBITMQ_HOST:-localhost:5672}
export NG_RABBITMQ_PASSWORD=${NG_RABBITMQ_PASSWORD:-guest}
export NG_RABBITMQ_USERNAME=${NG_RABBITMQ_USERNAME:-guest}
export K8S_CLUSTER=${K8S_CLUSTER:-docker-desktop}
export SVC_AWS_AUTH_MODE=${SVC_AWS_AUTH_MODE:-token}
export DB_CREDS="file:/etc/config/database.yml.erb"
export TZ=UTC
export LOG_CONF="config/log4j2.xml"
if [ ! -d /tmp/spa ] ; then
    mkdir /tmp/spa
fi
export TMP_DIR="/tmp/spa"
if [ "$ENVIRONMENT" = "development" ] ; then
  export DB_CREDS="file:/$SCRIPT_DIR/service/docker/sp-allocation/database.yml"
  export SVC_AWS_AUTH_MODE=vault:/tmp/ngdev_creds
  export K8S_NS=localhost
fi
echo "ENVIRONMENT VARIABLES set to:

K8S_NS:$K8S_NS,
KAFKA_HOST:$KAFKA_HOST,
NG_RABBITMQ_HOST:$NG_RABBITMQ_HOST,
K8S_CLUSTER:$K8S_CLUSTER,
SVC_AWS_AUTH_MODE:$SVC_AWS_AUTH_MODE,
TZ:$TZ,
AWS_REGION:$AWS_REGION
TMP_DIR:$TMP_DIR,
DB_CREDS:$DB_CREDS,
PRICING_URI:$PRICING_URI,
DYNAMODB_ROLE_ARN:$DYNAMODB_ROLE_ARN,
SP_ALLOCATION_STATUS_DYNAMODB_TABLE:$SP_ALLOCATION_STATUS_DYNAMODB_TABLE
SPA_VERSION:$SPA_VERSION
"

#-------------------------------------Setup JAR Filename----------------------------------------------------------------

export JAR_FILENAME="${SCRIPT_DIR}/cht-savings-plan-allocation-0.0.1.jar"
echo "JAR_FILENAME set to: $JAR_FILENAME"

#-------------------------------------Setup JVM Options-----------------------------------------------------------------

export JAVA_BASE_ARGS="$JAVA_OPTS $JAVA_MEMORY_ARGS -XX:+PrintGCTimeStamps -XshowSettings:vm"
echo "JAVA_BASE_ARGS set to: $JAVA_BASE_ARGS"

#-------------------------------------Setup Spark Options---------------------------------------------------------------

export SPARK_OPTS="-Dspark.driver.memory=20g -Dspark.driver.maxResultSize=4g -Dlog4j2.configurationFile=$LOG_CONF"
echo "SPARK_OPTS set to: $(echo $SPARK_OPTS | tr -s '\n' ' ')"

#-------------------------------------Run Savings Plan Allocation Module------------------------------------------------
echo ""
#Add to JVM args to debug: -agentlib:jdwp=transport=dt_socket,server=y,suspend=n,address=5005 \

# Set queue name based on job
QUEUE_NAME=$1

# if queue name is not set, default to sp-allocation for dev sandbox
if [ -z "$QUEUE_NAME" ] ; then
    QUEUE_NAME="sp-allocation"
fi

echo "Running spark application for rabbit queue: $QUEUE_NAME"
java $JAVA_BASE_ARGS $SPARK_OPTS \
     -cp "$JAR_FILENAME" \
     com.cloudhealthtech.savingsplan.SavingsPlanAllocation \
     server \
     --dbcreds "$DB_CREDS" \
     --s3creds "$SVC_AWS_AUTH_MODE" \
     --tmpdir "$TMP_DIR" \
     --clusterid "$K8S_NS" \
     --rabbiturl "$NG_RABBITMQ_HOST" \
     --rabbitpass "$NG_RABBITMQ_PASSWORD" \
     --rabbituser "$NG_RABBITMQ_USERNAME" \
     --queuename "$QUEUE_NAME" \
     --slaves 6 \
     --capacityPerSlave 1024 \
     --nonce 42 \
     --threadPool 8 \
     --local \
     --kafka "$KAFKA_HOST" \
     --rbenv "$ROLLBAR_ENV"
